package plenigo;

our $VERSION = '2.0000';

=head1 NAME

App::Meta - plenigo Perl SDK

=head1 DESCRIPTION

This is a .

=head1 AUTHOR

David Farrell

=head1 LICENSE

FreeBSD

=cut
